mednsktest
==========
https://github.com/idlesign/mednsktest


|release| |lic|

.. |release| image:: https://img.shields.io/pypi/v/mednsktest.svg
    :target: https://pypi.python.org/pypi/mednsktest

.. |lic| image:: https://img.shields.io/pypi/l/mednsktest.svg
    :target: https://pypi.python.org/pypi/mednsktest


Что это
-------

*Тесты с курсов НГМУ. Консольное приложение.*

При помощи этого приложения можно готовиться к тестам, являющимся частью программ обучения медработников,
проводящимся на базе Новосибирского Госудраственного Медицинского Университета.


В комплекте следующие наборы тестов:

1. Ультразвуковая диагностика
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   
Тесты 2013 года.

Подтверждённая актуальность: январь 2014.

Имя вопросника: 201401_uzd

2. Актуальные вопросы акушерства и гинекологии
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Тесты 2012 года.

Подтверждённая актуальность: февраль 2014.

Имя вопросника: 201402_gyne

3. Ультразвуковая диагностика
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Тесты 2018 года.

Подтверждённая актуальность: декабрь 2018.

Имя вопросника: 201812_uzd


Как установить
--------------

.. code-block:: bash

    $ pip install mednsktest


Как запустить
-------------

Приложение запускается из консоли при помощи команды:

.. code-block:: bash

    $ mednsktest start <имя_вопросника>


Например, запускаем вопросник по УЗИ:

.. code-block:: bash

    $ mednsktest 201401_uzd


По умолчанию выдаются 50 вопросов, выбранных случаным образом из общего количества, в случайном порядке.

Количество вопросов можно ограничить при помощи ключа ``--qlimit``.

Поддерживаются  и другие ключи. Помощь по ключам, которые принимает приложение, можно получить так:

.. code-block:: bash

    $ mednsktest start --help



Дополнительная информация
-------------------------

Файлы с тестами - обычные текстовые файлы, которые можно распечатать. Хранятся они в директории с приложением.

Приложение умеет разбирать тесты из файлов, если текст в них отформатирован следующим образом::

  #Вопрос 2
  Ультразвук - это звук, частота которого не ниже:
  #Варианты к вопросу 2
  № 1. 15 кГц;
  № 2. 20000 Гц;
  № 3. 1 МГц;
  № 4. 30 Гц;
  № 5. 20 Гц.
  #Ответ 2


Или так (правильный вариант ответа помечен `*****`)::

  #Вопрос 2
  Ультразвук - это звук, частота которого не ниже:
  #Варианты к вопросу
  № 1. 15 кГц;
  № 2. 20000 Гц; *****
  № 3. 1 МГц;
  № 4. 30 Гц;
  № 5. 20 Гц.
  #Ответ 0
